==> bea_flutter_package-0.76.129.tar.gz: lib/bea_services/core/bea_service_manager.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:bea_flutter_package/bea_flutter_package.dart';
import 'package:bea_flutter_package/bea_services/core/bea_account_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_defaults_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_files_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_mobile_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_network_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_roles_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_user_manager.dart';
import 'package:bea_flutter_package/bea_services/utils/key_utils.dart';
import 'package:bea_flutter_package/exceptions/bea_internet_exception.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:http/http.dart';

class BeaServiceManager{

  final String _baseUrl;
  final _storage = new FlutterSecureStorage();

  BeaDefaultsManager _beaDefaultsManager;
  BeaAccountManager _beaAccountManager;
  BeaUserManager _beaUserManager;
  BeaNetworkManager _beaNetworkManager;
  BeaFlutterPackage _beaFlutterPackage;
  BeaRolesManager _beaRolesManager;
  BeaFilesManager _beaFilesManager;
  BeaMobileManager _beaMobileManager;

  BeaServiceManager(BeaFlutterPackage bfp, this._baseUrl){
      try{
        _beaFlutterPackage = bfp;
        _beaNetworkManager = _beaFlutterPackage.getBeaNetworkManager();
      }on Exception catch (e){
        print('Initialization ${this.runtimeType.toString()} error');
        FLog.error(
            className: this.runtimeType.toString(),
            methodName: "Costructor",
            text: 'Initialization ${this.runtimeType.toString()} error - $e');
        throw e;
      }
  }

  //GETTERS AND SETTERS
  FlutterSecureStorage getBeaStorage(){
    return _storage;
  }

  BeaFlutterPackage getBeaFlutterPackage(){
    return _beaFlutterPackage;
  }

  BeaAccountManager getAccountManager(){
    if(_beaAccountManager == null){
      _beaAccountManager = new BeaAccountManager(this);
    }
    return _beaAccountManager;
  }

  BeaDefaultsManager getDefaultManager(){
    if(_beaDefaultsManager == null){
      _beaDefaultsManager = new BeaDefaultsManager(this);
    }
    return _beaDefaultsManager;
  }

  BeaUserManager getBeaUserManager(){
    if(_beaUserManager == null){
      _beaUserManager = new BeaUserManager(this);
    }
    return _beaUserManager;
  }

  BeaRolesManager getBeaRolesManager(){
    if(_beaRolesManager == null){
      _beaRolesManager = new BeaRolesManager(this);
    }
    return _beaRolesManager;
  }

  BeaMobileManager getBeaMobileManager(){
    if(_beaMobileManager == null){
      _beaMobileManager = new BeaMobileManager(this);
    }
    return _beaMobileManager;
  }

  BeaFilesManager getBeaFilesManager(){
    if(_beaFilesManager == null){
      _beaFilesManager = new BeaFilesManager(this);
    }
    return _beaFilesManager;
  }

  String getBaseUrl(){
    return _baseUrl;
  }

  static HttpClient getHttpClient() {
    HttpClient httpClient = new HttpClient()
      ..connectionTimeout = const Duration(seconds: 10);

    return httpClient;
  }

  //FUNCTIONS
  Future<Response> genericHttpPost(Map<String, String> headers, String url, String jsonInput) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      Response response = await post(url, headers: headers, body: jsonInput);
      return response;

    }on TimeoutException catch (_) {
        print('Request Timeout');
        FLog.error(
            className: this.runtimeType.toString(),
            methodName: "genericHttpPost",
            text: 'Request Timeout');
        throw new BeaInternetException("Request Timeout");
    }on Exception catch (e){
      print('Generic HTTP POST request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpPost",
          text: 'Generic HTTP POST request error - $e');
      throw e;
    }
  }

  Future<Response> genericHttpGet(String url, Map<String, String> headers) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      Response response = await get(url, headers: headers);
      return response;

    }on TimeoutException catch (_) {
      print('Request Timeout');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpGet",
          text: 'Request Timeout');
      throw new BeaInternetException("Request Timeout");
    }on Exception catch (e){
      print('Generic HTTP GET request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpGet",
          text: 'Generic HTTP Get request error - $e');
      throw e;
    }
  }

  Future<Response> genericBeaHttpPost(String url, String jsonInput) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      String token = await _storage.read(key: KeyUtils.KEY_TOKEN_SESSION);

      Map<String, String> headers = {
        "Authorization": "Bearer $token",
        "Content-Type": "application/json",
        "User-agent": "http.agent"
      };
      Response response = await post(url, headers: headers, body: jsonInput);

      if(response.statusCode == 400){
        print(response.body);
        throw new BeaInternetException("Input format value not valid");
      }

      return response;

    }on TimeoutException catch (_) {
      print('Request Timeout');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpPost",
          text: 'Request Timeout');
      throw new BeaInternetException("Request Timeout");
    } on BeaInternetException catch (e){
      print('BEA HTTP POST request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpPost",
          text: 'BEA HTTP POST request error - Input value format not valid - $e');
      throw new Exception(e);
    } on Exception catch (e){
      print('BEA HTTP POST request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpPost",
          text: 'BEA HTTP POST request error - $e');
      throw e;
    }
  }

  Future<Response> genericBeaHttpGet(String url) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      String token = await _storage.read(key: KeyUtils.KEY_TOKEN_SESSION);

      Map<String, String> headers = {
        "Authorization": "Bearer $token",
        "Content-Type": "application/json",
        "User-agent": "http.agent"
      };
      Response response = await get(url, headers: headers);

      if(response.statusCode == 400){
        print(response.body);
        throw new BeaInternetException("Input format value not valid");
      }

      return response;

    }on TimeoutException catch (_) {
      print('Request Timeout');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpGet",
          text: 'Request Timeout');
      throw new BeaInternetException("Request Timeout");
    }on BeaInternetException catch (e){
      print('BEA HTTP GET request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpGet",
          text: 'BEA HTTP GET request error - Input value format not valid - $e');
      throw new Exception(e);
    }on Exception catch (e){
      print('BEA HTTP GET request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpGet",
          text: 'BEA HTTP Get request error - $e');
      throw e;
    }
  }

  Future<String> getStorageUrl(int fileId) async{
    String token = await _storage.read(key: KeyUtils.KEY_TOKEN_SESSION);
    return '$_baseUrl/api/Storage?id=$fileId&access_token=$token';
  }
}

==> bea_flutter_package-1.0.0.tar.gz: lib/bea_services/core/bea_service_manager.dart <==
import 'dart:async';
import 'dart:io';

import 'package:bea_flutter_package/bea_flutter_package.dart';
import 'package:bea_flutter_package/bea_services/core/bea_account_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_defaults_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_files_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_mobile_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_network_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_roles_manager.dart';
import 'package:bea_flutter_package/bea_services/core/bea_user_manager.dart';
import 'package:bea_flutter_package/bea_services/utils/key_utils.dart';
import 'package:bea_flutter_package/exceptions/bea_internet_exception.dart';
import 'package:dio/dio.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';

class BeaServiceManager{

  final String _baseUrl;
  final _storage = new FlutterSecureStorage();

  BeaDefaultsManager _beaDefaultsManager;
  BeaAccountManager _beaAccountManager;
  BeaUserManager _beaUserManager;
  BeaNetworkManager _beaNetworkManager;
  BeaFlutterPackage _beaFlutterPackage;
  BeaRolesManager _beaRolesManager;
  BeaFilesManager _beaFilesManager;
  BeaMobileManager _beaMobileManager;

  BeaServiceManager(BeaFlutterPackage bfp, this._baseUrl){
      try{
        _beaFlutterPackage = bfp;
        _beaNetworkManager = _beaFlutterPackage.getBeaNetworkManager();
      }on Exception catch (e){
        print('Initialization ${this.runtimeType.toString()} error');
        FLog.error(
            className: this.runtimeType.toString(),
            methodName: "Costructor",
            text: 'Initialization ${this.runtimeType.toString()} error - $e');
        throw e;
      }
  }

  //GETTERS AND SETTERS
  FlutterSecureStorage getBeaStorage(){
    return _storage;
  }

  BeaFlutterPackage getBeaFlutterPackage(){
    return _beaFlutterPackage;
  }

  BeaAccountManager getAccountManager(){
    if(_beaAccountManager == null){
      _beaAccountManager = new BeaAccountManager(this);
    }
    return _beaAccountManager;
  }

  BeaDefaultsManager getDefaultManager(){
    if(_beaDefaultsManager == null){
      _beaDefaultsManager = new BeaDefaultsManager(this);
    }
    return _beaDefaultsManager;
  }

  BeaUserManager getBeaUserManager(){
    if(_beaUserManager == null){
      _beaUserManager = new BeaUserManager(this);
    }
    return _beaUserManager;
  }

  BeaRolesManager getBeaRolesManager(){
    if(_beaRolesManager == null){
      _beaRolesManager = new BeaRolesManager(this);
    }
    return _beaRolesManager;
  }

  BeaMobileManager getBeaMobileManager(){
    if(_beaMobileManager == null){
      _beaMobileManager = new BeaMobileManager(this);
    }
    return _beaMobileManager;
  }

  BeaFilesManager getBeaFilesManager(){
    if(_beaFilesManager == null){
      _beaFilesManager = new BeaFilesManager(this);
    }
    return _beaFilesManager;
  }

  String getBaseUrl(){
    return _baseUrl;
  }

  //FUNCTIONS
  Future<Response> genericHttpPost(String url,Map<String, String> headers, String jsonInput) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      var dio = Dio();
      dio.options
        ..connectTimeout = 10000 //10sec
        ..receiveTimeout = 10000 //10sec
        ..validateStatus = (int status) {
          return status > 0;
        }
        ..headers = headers;

      dio.interceptors
        ..add(InterceptorsWrapper(
          onError: (error){
            switch(error.type){
              case DioErrorType.CONNECT_TIMEOUT:
              case DioErrorType.RECEIVE_TIMEOUT:
              case DioErrorType.SEND_TIMEOUT:
                throw new Exception("Request in timeout - ${error.message}");
                break;
              case DioErrorType.RESPONSE:
                break;
              case DioErrorType.CANCEL:
                throw new Exception("Request cancelled - ${error.message}");
                break;
              case DioErrorType.DEFAULT:
                throw new Exception("Default error - ${error.message}");
                break;
            }
          }
          ));

      Response response = await dio.post(url, data: jsonInput);

      return response;

    }on Exception catch (e){
      print('Generic HTTP POST request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpPost",
          text: 'Generic HTTP POST request error - $e');
      throw e;
    }
  }

  Future<Response> genericHttpGet(String url, Map<String, String> headers) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      var dio = Dio();
      dio.options
        ..connectTimeout = 5000 //5s
        ..receiveTimeout = 5000
        ..validateStatus = (int status) {
          return status > 0;
        }
        ..headers = headers;

      dio.interceptors
        ..add(InterceptorsWrapper(
            onError: (error){
              switch(error.type){
                case DioErrorType.CONNECT_TIMEOUT:
                case DioErrorType.RECEIVE_TIMEOUT:
                case DioErrorType.SEND_TIMEOUT:
                  throw new Exception("Request in timeout - ${error.message}");
                  break;
                case DioErrorType.RESPONSE:
                  break;
                case DioErrorType.CANCEL:
                  throw new Exception("Request cancelled - ${error.message}");
                  break;
                case DioErrorType.DEFAULT:
                  throw new Exception("Default error - ${error.message}");
                  break;
              }
            }
        ));

      Response response = await dio.get(url);

      return response;

    } on Exception catch (e){
      print('Generic HTTP GET request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpGet",
          text: 'Generic HTTP Get request error - $e');
      throw e;
    }
  }

  Future<Response> genericBeaHttpPost(String url, String jsonInput) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      String token = await _storage.read(key: KeyUtils.KEY_TOKEN_SESSION);

      Map<String, String> headers = {
        "Authorization": "Bearer $token",
        "Content-Type": "application/json",
        "User-agent": "http.agent"
      };

      Response response = await genericHttpPost(url, headers, jsonInput);

      if(response.statusCode == 400){
        print(response.data);
        throw new BeaInternetException("Input format value not valid");
      }

      return response;

    }on TimeoutException catch (_) {
      print('Request Timeout');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpPost",
          text: 'Request Timeout');
      throw new BeaInternetException("Request Timeout");
    } on BeaInternetException catch (e){
      print('BEA HTTP POST request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpPost",
          text: 'BEA HTTP POST request error - Input value format not valid - $e');
      throw new Exception(e);
    } on Exception catch (e){
      print('BEA HTTP POST request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpPost",
          text: 'BEA HTTP POST request error - $e');
      throw e;
    }
  }

  Future<Response> genericBeaHttpGet(String url) async {
    try{

      if(!await _beaNetworkManager.checkNetworkConnection()){
        throw new BeaInternetException("No internet connection");
      }

      String token = await _storage.read(key: KeyUtils.KEY_TOKEN_SESSION);

      Map<String, String> headers = {
        "Authorization": "Bearer $token",
        "Content-Type": "application/json",
        "User-agent": "http.agent"
      };
      Response response = await genericHttpGet(url, headers);

      if(response.statusCode == 400){
        print(response.data);
        throw new BeaInternetException("Input format value not valid");
      }

      return response;

    }on TimeoutException catch (_) {
      print('Request Timeout');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericHttpGet",
          text: 'Request Timeout');
      throw new BeaInternetException("Request Timeout");
    }on BeaInternetException catch (e){
      print('BEA HTTP GET request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpGet",
          text: 'BEA HTTP GET request error - Input value format not valid - $e');
      throw new Exception(e);
    }on Exception catch (e){
      print('BEA HTTP GET request error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "genericBeaHttpGet",
          text: 'BEA HTTP Get request error - $e');
      throw e;
    }
  }

  Future<String> getStorageUrl(int fileId) async{
    String token = await _storage.read(key: KeyUtils.KEY_TOKEN_SESSION);
    return '$_baseUrl/api/Storage?id=$fileId&access_token=$token';
  }
}
